@@ -30,6 +30,9 @@ Catmandu::Fix::Inline::marc_map - A marc_map-er for Perl scripts
  # Get all 100 subfields except the digits
  $str = marc_map($data,'100^0123456789');
 
+ # If the 260c exist set the output to 'OK' (else undef)
+ $ok  = marc_map($data,'260c',-value => 'OK');
+
  # The $data should be a Catmandu-style MARC hash
  { record => [
     ['field', 'ind1' , 'ind2' , 'subfieldcode or underscore' , 'data' , 'subfield' , 'data' , ...] ,
@@ -45,7 +48,9 @@ Catmandu::Fix::Inline::marc_map - A marc_map-er for Perl scripts
 
 =head1 SEE ALSO
 
-L<Catmandu::Fix::Inline::marc_add> , L<Catmandu::Fix::Inline::marc_remove> 
+L<Catmandu::Fix::Inline::marc_set> , 
+L<Catmandu::Fix::Inline::marc_add> , 
+L<Catmandu::Fix::Inline::marc_remove> 
 
 =cut
 
@@ -57,6 +62,8 @@ require Exporter;
 @EXPORT_OK = qw(marc_map);
 %EXPORT_TAGS = (all => [qw(marc_map)]);
 
+our $VERSION = '0.216';
+
 sub marc_map {
     my ($data,$marc_path,%opts) = @_;
 
@@ -71,9 +78,10 @@ sub marc_map {
     my $split     = $opts{'-split'};
     my $join_char = $opts{'-join'} // '';
     my $pluck     = $opts{'-pluck'};
+    my $value_set = $opts{'-value'};
     my $attrs     = {};
 
-    if ($marc_path =~ /(\S{3})(\[(.)?,?(.)?\])?([_a-z0-9^]+)?(\/(\d+)(-(\d+))?)?/) {
+    if ($marc_path =~ /(\S{3})(\[([^,])?,?([^,])?\])?([_a-z0-9^]+)?(\/(\d+)(-(\d+))?)?/) {
         $attrs->{field}          = $1;
         $attrs->{ind1}           = $3;
         $attrs->{ind2}           = $4;
@@ -123,27 +131,37 @@ sub marc_map {
 
     	my $v;
 
-    	if ($var->[0] =~ /LDR|00./) {
-    		$v = $add_subfields->($var,3);
-    	}
-    	elsif (defined $var->[5] && $var->[5] eq '_') {
-    		$v = $add_subfields->($var,5);
-    	}
-    	else {
-    		$v = $add_subfields->($var,3);
-    	}
+        if ($value_set) {
+            for (my $i = 3; $i < @$var; $i += 2) {
+                if ($var->[$i] =~ /$attrs->{subfield_regex}/) {
+                    $v = $value_set;
+                    last;
+                }
+            }
+        }
+        else {
+        	if ($var->[0] =~ /LDR|00./) {
+        		$v = $add_subfields->($var,3);
+        	}
+        	elsif (defined $var->[3] && $var->[3] eq '_') {
+        		$v = $add_subfields->($var,5);
+        	}
+        	else {
+        		$v = $add_subfields->($var,3);
+        	}
 
-    	if (@$v) {
-    		if (!$split) {
-    			$v = join $join_char, @$v;
+        	if (@$v) {
+        		if (!$split) {
+        			$v = join $join_char, @$v;
+                }
 
     			if (defined(my $off = $attrs->{from})) {
+                    $v = join $join_char, @$v if (ref $v eq 'ARRAY');
     				my $len = defined $attrs->{to} ? $attrs->{to} - $off + 1 : 1;
     				$v = substr($v,$off,$len);
     			}
-    		}
-    	}
-
+        	}
+        }
     	push (@vals,$v) if ( (ref $v eq 'ARRAY' && @$v) || (ref $v eq '' && length $v ));
     }
 
