@@ -5,6 +5,10 @@ use Catmandu::Util qw(:is);
 use Moo;
 use Catmandu::Fix::Has;
 
+with 'Catmandu::Fix::Inlineable';
+
+our $VERSION = '0.216';
+
 has marc_tag    => (fix_arg => 1);
 has subfields   => (fix_arg => 'collect');
 
