@@ -5,6 +5,8 @@ use Carp qw(confess);
 use Moo;
 use Catmandu::Fix::Has;
 
+our $VERSION = '0.216';
+
 has marc_path      => (fix_arg => 1);
 has path           => (fix_arg => 1);
 has record         => (fix_opt => 1);
@@ -23,7 +25,7 @@ sub emit {
     my $field_regex;
     my ($field,$ind1,$ind2,$subfield_regex,$from,$to);
 
-    if ($marc_path =~ /(\S{3})(\[(.)?,?(.)?\])?([_a-z0-9^]+)?(\/(\d+)(-(\d+))?)?/) {
+    if ($marc_path =~ /(\S{3})(\[([^,])?,?([^,])?\])?([_a-z0-9^]+)?(\/(\d+)(-(\d+))?)?/) {
         $field          = $1;
         $ind1           = $3;
         $ind2           = $4;
@@ -42,7 +44,6 @@ sub emit {
     my $vals = $fixer->generate_var;
     my $perl = $fixer->emit_declare_vars($vals, '[]');
 
-
     $perl .= $fixer->emit_foreach("${var}->{${record_key}}", sub {
         my $var  = shift;
         my $v    = $fixer->generate_var;
@@ -60,8 +61,14 @@ sub emit {
         if ($self->value) {
             $perl .= $fixer->emit_declare_vars($v, $fixer->emit_string($self->value));
             $perl .= $fixer->emit_create_path($fixer->var, $path, sub {
-                my $var = shift;
-                "${var} = ${v};";
+                my $var2 = shift;
+                my $i = $fixer->generate_var;
+                return 
+                "for (my ${i} = 3; ${i} < \@{${var}}; ${i} += 2) {".
+                    "if (${var}->[${i}] =~ /${subfield_regex}/) {".
+                        "${var2} = ${v}; last;".
+                    "}".
+                "}";
             });
         } else {
             my $i = $fixer->generate_var;
@@ -95,38 +102,51 @@ sub emit {
             # Old Catmandu::MARC contained a bug/feature to allow
             # for '_' subfields in non-control elements ..for beackwards
             # compatibility we ignore them
-            $perl .= "} elsif (defined ${var}->[5] && ${var}->[5] eq '_') {";
+            $perl .= "} elsif (defined ${var}->[3] && ${var}->[3] eq '_') {";
             $perl .= $add_subfields->(5);
             $perl .= "} else {";
             $perl .= $add_subfields->(3);
             $perl .= "}";
             $perl .= "if (\@{${v}}) {";
+
             if (!$self->split) {
                 $perl .= "${v} = join(${join_char}, \@{${v}});";
-                if (defined(my $off = $from)) {
-                    my $len = defined $to ? $to - $off + 1 : 1;
-                    $perl .= "if (eval { ${v} = substr(${v}, ${off}, ${len}); 1 }) {";
-                }
             }
+
+            if (defined(my $off = $from)) {
+                my $len = defined $to ? $to - $off + 1 : 1;
+                $perl .= "${v} = join(${join_char}, \@{${v}}) if (is_array_ref(${v}));";
+                $perl .= "if (length(${v}) > ${off}) {" .
+                         "  ${v} = substr(${v}, ${off}, ${len});" .
+                         "} else {" .
+                         "  ${v} = undef;".
+                         "}";
+            }
+        
             $perl .= $fixer->emit_create_path($fixer->var, $path, sub {
                 my $var = shift;
+                my $perl = "";
+                $perl .= "if (defined ${v}) {";
                 if ($self->split) {
+                    $perl .= 
+                    "${v} = [ ${v} ] unless ref ${v} eq 'ARRAY';" .
                     "if (is_array_ref(${var})) {".
-                        "push \@{${var}}, ${v};".
+                        "push \@{${var}}, \@{${v}};".
                     "} else {".
-                        "${var} = [${v}];".
+                        "${var} = [\@{${v}}];".
                     "}";
                 } else {
+                    $perl .= 
                     "if (is_string(${var})) {".
                         "${var} = join(${join_char}, ${var}, ${v});".
                     "} else {".
                         "${var} = ${v};".
                     "}";
                 }
-            });
-            if (defined($from)) {
                 $perl .= "}";
-            }
+                $perl;
+            });
+        
             $perl .= "}";
         }
         $perl;
@@ -143,10 +163,10 @@ Catmandu::Fix::marc_map - copy marc values of one field to a new field
 
 =head1 SYNOPSIS
 
-    # Append all 245 subfields to my.title
-    marc_map('245','my.title')
+    # Append all 245 subfields to my.title field the values are joined into one string 
+    marc_map('245','my.title') 
 
-    # Append an array of 245 subfields to the my.title array
+    # Append al 245 subfields to the my.title keeping all subfields as an array
     marc_map('245','my.title', split:1)
 
     # Copy the 245-$a$b$c subfields into the my.title hash in the order provided in the record
@@ -163,9 +183,9 @@ Catmandu::Fix::marc_map - copy marc values of one field to a new field
 
     # Copy the 600-$x subfields into the my.subjects array while packing each into a genre.text hash
     marc_map('600x','my.subjects.$append.genre.text')
-
+    
     # Copy the 008 characters 35-35 into the my.language hash
-    marc_map('008_/35-35','my.language')
+    marc_map('008/35-35','my.language')
 
     # Copy all the 600 fields into a my.stringy hash joining them by '; '
     marc_map('600','my.stringy', join:'; ')
@@ -173,6 +193,9 @@ Catmandu::Fix::marc_map - copy marc values of one field to a new field
     # When 024 field exists create the my.has024 hash with value 'found'
     marc_map('024','my.has024', value:found)
 
+    # When 260c field exists create the my.has260c hash with value 'found'
+    marc_map('260c','my.has260c', value:found)
+
     # Do the same examples now with the marc fields in 'record2'
     marc_map('245','my.title', record:record2)
 
@@ -185,6 +208,12 @@ Catmandu::Fix::marc_map - copy marc values of one field to a new field
     # Map the 100-a field where indicator-1 is 3
     marc_map('100[3]a','name.family')
 
+    # Map the 245-a field where indicator-2 is 0
+    marc_map('245[,0]a','title')
+
+    # Map the 245-a field where indicator-1 is 1 and indicator-2 is 0
+    marc_map('245[1,0]a','title')
+
 =head1 DESCRIPTION
 
 Read our Wiki pages at L<https://github.com/LibreCat/Catmandu/wiki/Fixes> for a complete
